pub enum MaskCompose {
Add,
Subtract,
Intersect,
Exclude,
}Expand description
Operador de combinación entre capas de máscara (CSS mask-composite). Mapea
a un Compose Porter-Duff de vello cuando una capa extra se compone sobre
las de abajo. Fase 7.1231.
Variants
Add
La capa se suma sobre las de abajo (source-over). Default CSS.
Subtract
La capa resta (source-out: la fuente donde NO solapa el destino).
Intersect
Intersección (source-in: la fuente donde solapa el destino).
Exclude
Exclusión (xor: las regiones no solapadas de ambas).