pub struct Ripple {
pub key: u64,
pub color: AlphaColor<Srgb>,
pub duration: Duration,
}Expand description
Declara que este nodo emite un ripple (salpicadura Material) al recibir
un press. key debe ser estable entre rebuilds del View (igual que la
key de crate::Anim) — es lo que enlaza la salpicadura retenida con el
nodo entre frames. color es el tinte de la onda (típicamente
semitransparente, p. ej. blanco a alpha ~0.25 sobre superficies oscuras o
negro a alpha ~0.12 sobre claras); su alpha se multiplica por el fade.
Fields
key: u64color: AlphaColor<Srgb>duration: DurationTrait Implementations